@@ -16,6 +16,22 @@
 # You should have received a copy of the GNU General Public License
 # along with orix.  If not, see <http://www.gnu.org/licenses/>.
 
+"""Input/output plugins.
+
+.. currentmodule:: orix.io.plugins
+
+.. rubric:: Modules
+
+.. autosummary::
+    :toctree: ../generated/
+    :template: custom-module-template.rst
+
+    ang
+    bruker_h5ebsd
+    emsoft_h5ebsd
+    orix_hdf5
+"""
+
 from orix.io.plugins import ang, bruker_h5ebsd, emsoft_h5ebsd, orix_hdf5
 
 plugin_list = [
