@@ -16,12 +16,17 @@
 # You should have received a copy of the GNU General Public License
 # along with orix.  If not, see <http://www.gnu.org/licenses/>.
 
-import matplotlib.patches as mpatches
+from typing import List, Optional, Tuple
+
 from matplotlib.axes import Axes
+import matplotlib.colorbar as mbar
 from matplotlib.image import AxesImage
+import matplotlib.patches as mpatches
 from matplotlib.projections import register_projection
+import matplotlib.pyplot as plt
+from matplotlib_scalebar.dimension import _Dimension
+from matplotlib_scalebar.scalebar import ScaleBar
 from mpl_toolkits.axes_grid1 import make_axes_locatable
-from matplotlib_scalebar import dimension, scalebar
 import numpy as np
 
 
@@ -39,87 +44,84 @@ class CrystalMapPlot(Axes):
 
     def plot_map(
         self,
-        crystal_map,
-        value=None,
-        scalebar=True,
-        scalebar_properties=None,
-        legend=True,
-        legend_properties=None,
-        axes=None,
-        depth=None,
-        override_status_bar=False,
+        crystal_map: "orix.crystal_map.CrystalMap",
+        value: Optional[np.ndarray] = None,
+        scalebar: bool = True,
+        scalebar_properties: Optional[dict] = None,
+        legend: bool = True,
+        legend_properties: Optional[dict] = None,
+        axes: Tuple[int] = None,
+        depth: Optional[int] = None,
+        override_status_bar: bool = False,
         **kwargs,
     ) -> AxesImage:
-        r"""Plot a 2D map with any CrystalMap attribute as map values.
+        """Plot a 2D map with any CrystalMap attribute as map values.
 
         Wraps :meth:`matplotlib.axes.Axes.imshow`, see that method for
         relevant keyword arguments.
 
         Parameters
         ----------
-        crystal_map : orix.crystal_map.CrystalMap
+        crystal_map
             Crystal map object to obtain data to plot from.
-        value : numpy.ndarray, optional
-            Attribute array to plot. If value is None (default), a phase
-            map is plotted.
-        scalebar : bool, optional
-            Whether to add a scalebar (default is True) along the
+        value
+            Attribute array to plot. If value is ``None`` (default), a
+            phase map is plotted.
+        scalebar
+            Whether to add a scalebar (default is ``True``) along the
             horizontal map dimension.
-        scalebar_properties : dict
+        scalebar_properties
             Dictionary of keyword arguments passed to
-            :func:`mpl_toolkits.axes_grid1.anchored_artists.AnchoredSizeBar`.
-        legend : bool, optional
+            :class:`mpl_toolkits.axes_grid1.anchored_artists.AnchoredSizeBar`.
+        legend
             Whether to add a legend to the plot. This is only
             implemented for a phase plot (in which case default is
-            True).
-        legend_properties : dict
+            ``True``).
+        legend_properties
             Dictionary of keyword arguments passed to
-            :meth:`matplotlib.axes.legend`.
-        axes : tuple of ints, optional
+            :meth:`matplotlib.axes.Axes.legend`.
+        axes
             Which data axes to plot if data has more than two
             dimensions. The index of data to plot in the final dimension
-            is determined by `depth`. If None (default), data along the
-            two last axes is plotted.
-        depth : int, optional
+            is determined by ``depth``. If ``None`` (default), data
+            along the two last axes is plotted.
+        depth
             Which layer along the third axis to plot if data has more
-            than two dimensions. If None (default), data in the first
-            index (layer) is plotted.
-        override_status_bar : bool, optional
+            than two dimensions. If ``None`` (default), data in the
+            first index (layer) is plotted.
+        override_status_bar
             Whether to display Euler angles and any overlay values in
             the status bar when hovering over the map (default is
-            False).
-        kwargs
+            ``False``).
+        **kwargs
             Keyword arguments passed to
             :meth:`matplotlib.axes.Axes.imshow`.
 
         Returns
         -------
-        im : matplotlib.image.AxesImage
+        im
             Image object, to be used further to get data from etc.
 
         See Also
         --------
         matplotlib.axes.Axes.imshow
-        orix.plot.CrystalMapPlot.add_scalebar
-        orix.plot.CrystalMapPlot.add_overlay
-        orix.plot.CrystalMapPlot.add_colorbar
+        add_scalebar
+        add_overlay
+        add_colorbar
 
         Examples
         --------
-        >>> import matplotlib.pyplot as plt
-        >>> import numpy as np
-        >>> from orix import plot
+        >>> from orix import data, plot
         >>> from orix.io import load
 
         Import a crystal map
 
-        >>> xmap = load("/some/directory/data.ang")
+        >>> xmap = data.sdss_ferrite_austenite()
 
         Plot a phase map
 
-        >>> fig = plt.figure()  # Get figure
-        >>> ax = fig.add_subplot(projection="plot_map")  # Get axes
-        >>> im = ax.plot_map(xmap)  # Get image
+        >>> fig, ax = plt.subplots(subplot_kw=dict(projection="plot_map"))
+        >>> _ = ax.plot_map(xmap)
 
         Add an overlay
 
@@ -128,9 +130,7 @@ class CrystalMapPlot(Axes):
         Plot an arbitrary map property, also changing scalebar location
 
         >>> ax = plt.subplot(projection="plot_map")
-        >>> ax.plot_map(
-        ...     xmap, xmap.dp, cmap="cividis", scalebar_properties={"loc": 4}
-        ... )
+        >>> _ = ax.plot_map(xmap, xmap.dp, scalebar_properties={"location": 4})
 
         Add a colorbar
 
@@ -143,23 +143,19 @@ class CrystalMapPlot(Axes):
         >>> fig = plt.figure()
         >>> ax = fig.add_subplot(projection="plot_map")
         >>> im = ax.plot_map(xmap2, austenite_angles)
-        >>> ax.add_colorbar("Orientation angle [$^{\circ}$]")
+        >>> _ = ax.add_colorbar("Orientation angle [deg]")
 
         Remove all figure and axes padding
 
-        >>> ax.remove_padding()
+        >>> _ = ax.remove_padding()
 
         Write annotated figure to file
 
-        >>> fig.savefig(
-        ...     "/some/directory/image.png",
-        ...     pad_inches=0,
-        ...     bbox_inches="tight"
-        ... )
+        >>> #fig.savefig("image.png", pad_inches=0, bbox_inches="tight")
 
         Write un-annotated image to file
 
-        >>> plt.imsave("/some/directory/image2.png", im.get_array())
+        >>> #plt.imsave("image2.png", im.get_array())
         """
         self._set_plot_shape(crystal_map=crystal_map, axes=axes, depth=depth)
 
@@ -205,32 +201,30 @@ class CrystalMapPlot(Axes):
 
         return im
 
-    def add_scalebar(self, crystal_map, **kwargs):
+    def add_scalebar(
+        self, crystal_map: "orix.crystal_map.CrystalMap", **kwargs
+    ) -> ScaleBar:
         """Add a scalebar to the axes instance and return it.
 
         The scalebar is also available as an attribute :attr:`scalebar`.
 
         Parameters
         ----------
-        crystal_map : orix.crystal_map.CrystalMap
+        crystal_map
             Crystal map instance to obtain necessary data from.
-        kwargs
+        **kwargs
             Keyword arguments passed to
             :class:`matplotlib_scalebar.scalebar.ScaleBar`.
 
         Returns
         -------
-        bar : matplotlib_scalebar.scalebar.ScaleBar
+        bar
             Scalebar.
 
         Examples
         --------
-        >>> xmap
-        Phase  Orientations   Name       Symmetry  Color
-        1      5657 (48.4%)   austenite  432       tab:blue
-        2      6043 (51.6%)   ferrite    432       tab:orange
-        Properties: iq, dp
-        Scan unit: um
+        >>> from orix import data, plot
+        >>> xmap = data.sdss_ferrite_austenite()
 
         Create a phase map without a scale bar and add it afterwards
 
@@ -250,7 +244,7 @@ class CrystalMapPlot(Axes):
         elif scan_unit[-1] == "m":
             dim = "si-length"  # Default
         else:
-            dim = dimension._Dimension(scan_unit)
+            dim = _Dimension(scan_unit)
 
         # Set up arguments to AnchoredSizeBar() if not already present in kwargs
         d = dict(
@@ -264,7 +258,7 @@ class CrystalMapPlot(Axes):
         [kwargs.setdefault(k, v) for k, v in d.items()]
 
         # Create scalebar
-        bar = scalebar.ScaleBar(
+        bar = ScaleBar(
             dx=crystal_map._step_sizes[horizontal],
             units=crystal_map.scan_unit,
             **kwargs,
@@ -274,7 +268,7 @@ class CrystalMapPlot(Axes):
 
         return bar
 
-    def add_overlay(self, crystal_map, item):
+    def add_overlay(self, crystal_map: "orix.crystal_map.CrystalMap", item: str):
         """Use a crystal map property as gray scale values of a phase
         map.
 
@@ -282,20 +276,16 @@ class CrystalMapPlot(Axes):
 
         Parameters
         ----------
-        crystal_map : orix.crystal_map.CrystalMap
+        crystal_map
             Crystal map object to obtain necessary data from.
-        item : str
+        item
             Name of map property to scale phase array with. The property
             range is adjusted for maximum contrast.
 
         Examples
         --------
-        >>> xmap
-        Phase  Orientations   Name       Symmetry  Color
-        1      5657 (48.4%)   austenite  432       tab:blue
-        2      6043 (51.6%)   ferrite    432       tab:orange
-        Properties: iq, dp
-        Scan unit: um
+        >>> from orix import data, plot
+        >>> xmap = data.sdss_ferrite_austenite()
 
         Plot a phase map with a map property as overlay
 
@@ -303,7 +293,6 @@ class CrystalMapPlot(Axes):
         >>> ax = fig.add_subplot(projection="plot_map")
         >>> im = ax.plot_map(xmap)
         >>> ax.add_overlay(xmap, xmap.dp)
-
         """
         image = self.images[0]
         image_data = image.get_array()
@@ -323,32 +312,30 @@ class CrystalMapPlot(Axes):
 
         image.set_data(image_data)
 
-    def add_colorbar(self, label=None, **kwargs):
+    def add_colorbar(self, label: Optional[str] = None, **kwargs) -> mbar.Colorbar:
         """Add an opinionated colorbar to the figure and return it.
 
         The colorbar is also available as an attribute :attr:`colorbar`.
 
         Parameters
         ----------
-        label : str, optional
+        label
             Colorbar title, default is ``None``.
-        kwargs
+        **kwargs
             Keyword arguments passed to
             :meth:`mpl_toolkits.axes_grid1.make_axes_locatable.append_axes`.
 
         Returns
         -------
-        cbar : matplotlib.colorbar
+        cbar
             Colorbar.
 
         Examples
         --------
-        >>> xmap
-        Phase  Orientations   Name       Symmetry  Color
-        1      5657 (48.4%)   austenite  432       tab:blue
-        2      6043 (51.6%)   ferrite    432       tab:orange
-        Properties: iq, dp
-        Scan unit: um
+        >>> from orix import data
+        >>> xmap = data.sdss_ferrite_austenite()
+        >>> xmap.scan_unit
+        'um'
 
         Plot a map property and add a colorbar
 
@@ -360,7 +347,7 @@ class CrystalMapPlot(Axes):
         If the default options are not satisfactory, the colorbar can be
         updated
 
-        >>> cbar.ax.set_ylabel(ylabel="dp", rotation=90)
+        >>> _ = cbar.ax.set_ylabel(ylabel="dp", rotation=90)
         """
         # Keyword arguments
         d = {"position": "right", "size": "5%", "pad": 0.1}
@@ -384,18 +371,14 @@ class CrystalMapPlot(Axes):
 
         Examples
         --------
-        >>> xmap
-        Phase  Orientations   Name       Symmetry  Color
-        1      5657 (48.4%)   austenite  432       tab:blue
-        2      6043 (51.6%)   ferrite    432       tab:orange
-        Properties: iq, dp
-        Scan unit: um
+        >>> from orix import data, plot
+        >>> xmap = data.sdss_ferrite_austenite()
 
         Remove all figure and axes padding of a phase map
 
         >>> fig = plt.figure()
         >>> ax = fig.add_subplot(projection="plot_map")
-        >>> ax.plot_map(xmap)
+        >>> _ = ax.plot_map(xmap)
         >>> ax.remove_padding()
         """
         self.set_axis_off()
@@ -409,21 +392,26 @@ class CrystalMapPlot(Axes):
             right = 1
         self.figure.subplots_adjust(top=1, bottom=0, right=right, left=0)
 
-    def _set_plot_shape(self, crystal_map, axes=None, depth=None):
+    def _set_plot_shape(
+        self,
+        crystal_map: "orix.crystal_map.CrystalMap",
+        axes: Optional[List[int]] = None,
+        depth: Optional[int] = None,
+    ):
         """Set `CrystalMapPlot` attributes describing which data axes to
         plot.
 
         Parameters
         ----------
-        crystal_map : orix.crystal_map.CrystalMap
+        crystal_map
             Map to determine plotting axes and slices from.
-        axes : list of ints, optional
+        axes
             Data axes to plot. If ``None``, the last two data axes are
             plotted (default).
-        depth : int, optional
-            Which data layer to plot along the final axis not in `axes` if
-            data is 3D. If ``None``, this is set to zero, i.e. the first
-            layer (default).
+        depth
+            Which data layer to plot along the final axis not in `axes`
+            if data is 3D. If ``None``, this is set to zero, i.e. the
+            first layer (default).
         """
         ndim = crystal_map.ndim
 
@@ -452,14 +440,14 @@ class CrystalMapPlot(Axes):
         self._data_slices = tuple(slices)
         self._data_shape = tuple(data_shape)
 
-    def _add_legend(self, patches, **kwargs):
+    def _add_legend(self, patches: List[mpatches.Patch], **kwargs):
         """Add a legend to the axes object.
 
         Parameters
         ----------
-        patches : list of matplotlib.patches.Patch
+        patches
             Patches with color code and name.
-        kwargs
+        **kwargs
             Keyword arguments passed to :meth:`matplotlib.axes.legend`.
         """
         d = {
@@ -471,7 +459,9 @@ class CrystalMapPlot(Axes):
         [kwargs.setdefault(k, v) for k, v in d.items()]
         self.legend(handles=patches, **kwargs)
 
-    def _override_status_bar(self, image, crystal_map):
+    def _override_status_bar(
+        self, image: AxesImage, crystal_map: "orix.crystal_map.CrystalMap"
+    ) -> AxesImage:
         """Display coordinates, a property value (if scalar values are
         plotted), and Euler angles (in radians) per data point in the
         status bar.
@@ -483,15 +473,16 @@ class CrystalMapPlot(Axes):
 
         Parameters
         ----------
-        image : matplotlib.images.AxesImage
-            Image object.
-        crystal_map : orix.crystal_map.CrystalMap
+        image
+            Image.
+        crystal_map
             Crystal map object to obtain necessary data from.
 
         Returns
         -------
-        image : matplotlib.images.AxesImage
-            Image object where the above mentioned methods are overridden.
+        image
+            Image object where the above mentioned methods are
+            overridden.
         """
         # Get data shape to plot
         n_rows, n_cols = self._data_shape
