@@ -16,50 +16,65 @@
 # You should have received a copy of the GNU General Public License
 # along with orix.  If not, see <http://www.gnu.org/licenses/>.
 
+from typing import Optional, Union
+
 import numpy as np
 
-from orix.quaternion import OrientationRegion
+from orix.quaternion import OrientationRegion, Rotation, Symmetry
 from orix.quaternion.symmetry import get_point_group
-from orix.sampling.SO3_sampling import uniform_SO3_sample, _three_uniform_samples_method
+from orix.sampling.SO3_sampling import _three_uniform_samples_method, uniform_SO3_sample
 from orix.sampling._cubochoric_sampling import cubochoric_sampling
 
 
 def get_sample_fundamental(
-    resolution=2, point_group=None, space_group=None, method="cubochoric", **kwargs
-):
-    """Generates an equispaced grid of rotations within a fundamental
-    zone.
+    resolution: Union[int, float] = 2,
+    point_group: Optional[Symmetry] = None,
+    space_group: Optional[int] = None,
+    method: str = "cubochoric",
+    **kwargs
+) -> Rotation:
+    """Return an equispaced grid of rotations within a fundamental zone.
 
     Parameters
     ----------
-    resolution : float, optional
+    resolution
         The characteristic distance between a rotation and its neighbour
         in degrees.
-    point_group : orix.quaternion.Symmetry, optional
-        One of the 11 proper point groups. If not given, `space_group`
+    point_group
+        One of the 11 proper point groups. If not given, ``space_group``
         must be.
-    space_group: int, optional
-        Between 1 and 231. Must be given if `point_group` is not.
-    method : str, optional
-        "cubochoric" (default), "haar_euler", or, "quaternion". See
-        :func:`~orix.sampling.uniform_SO3_sample` for details.
-    kwargs
+    space_group
+        Between 1 and 231. Must be given if ``point_group`` is not.
+    method
+        ``"cubochoric"`` (default), ``"haar_euler"`` or
+        ``"quaternion"``. See :func:`~orix.sampling.uniform_SO3_sample`
+        for details.
+    **kwargs
         Keyword arguments passed on to the sampling method.
 
     Returns
     -------
-    rot : ~orix.quaternion.Rotation
+    rot
         Grid of rotations lying within the specified fundamental zone.
 
     See Also
     --------
-    :func:`orix.sampling.uniform_SO3_sample`
+    orix.sampling.uniform_SO3_sample
 
     Examples
     --------
-    >>> from orix.quaternion.symmetry import C2
+    >>> from orix.quaternion.symmetry import Oh
     >>> from orix.sampling import get_sample_fundamental
-    >>> rot = get_sample_fundamental(1, point_group=C2)
+    >>> rot = get_sample_fundamental(5, point_group=Oh)
+    >>> rot
+    Rotation (6579,)
+    [[ 0.877  -0.2774 -0.2774 -0.2774]
+     [ 0.877  -0.2884 -0.2884 -0.2538]
+     [ 0.877  -0.2986 -0.2986 -0.2291]
+     ...
+     [ 0.877   0.2986  0.2986  0.2291]
+     [ 0.877   0.2884  0.2884  0.2538]
+     [ 0.877   0.2774  0.2774  0.2774]]
     """
     if point_group is None:
         point_group = get_point_group(space_group, proper=True)
@@ -76,35 +91,40 @@ def get_sample_fundamental(
 
 
 def get_sample_local(
-    resolution=2, center=None, grid_width=10, method="cubochoric", **kwargs
-):
-    """Generates a grid of rotations about a given rotation.
+    resolution: Union[int, float] = 2,
+    center: Optional[Rotation] = None,
+    grid_width: Union[int, float] = 10,
+    method: str = "cubochoric",
+    **kwargs
+) -> Rotation:
+    """Return a grid of rotations about a given rotation.
 
     Parameters
     ----------
-    resolution : float, optional
+    resolution
         The characteristic distance between a rotation and its neighbour
         in degrees.
-    center : ~orix.quaternion.Rotation, optional
+    center
         The rotation at which the grid is centered. The identity is used
         if not given.
-    grid_width : float, optional
+    grid_width
         The largest angle of rotation in degrees away from center that
         is acceptable.
-    method : str, optional
-        "cubochoric", "haar_euler", or "quaternion". See
-        :func:`~orix.sampling.uniform_SO3_sample` for details.
-    kwargs
+    method
+        ``"cubochoric"`` (default), ``"haar_euler"`` or
+        ``"quaternion"``. See :func:`~orix.sampling.uniform_SO3_sample`
+        for details.
+    **kwargs
         Keyword arguments passed on to the sampling method.
 
     Returns
     -------
-    r : ~orix.quaternion.Rotation
-        Grid of rotations lying within `grid_width` of center.
+    rot
+        Grid of rotations lying within ``grid_width`` of center.
 
     See Also
     --------
-    :func:`orix.sampling.uniform_SO3_sample`
+    orix.sampling.uniform_SO3_sample
     """
     if method == "haar_euler":
         rot = uniform_SO3_sample(resolution, method=method, unique=False)
@@ -124,24 +144,24 @@ def get_sample_local(
     return rot
 
 
-def _remove_larger_than_angle(r, max_angle):
-    """Removes large angle rotations from a sample of rotations.
+def _remove_larger_than_angle(rot: Rotation, max_angle: Union[int, float]) -> Rotation:
+    """Remove large angle rotations from a sample of rotations.
 
     Parameters
     ----------
-    r : ~orix.quaternion.Rotation
+    rot
         Sample of rotations.
-    max_angle : float
+    max_angle
         Maximum allowable angle (in degrees) from which a rotation can
         differ from the origin.
 
     Returns
     -------
-    r : ~orix.quaternion.Rotation
+    rot_out
         Rotations lying within the desired region.
     """
     half_angle = np.deg2rad(max_angle / 2)
-    half_angles = np.arccos(r.a.data)  # Returns between 0 and pi
+    half_angles = np.arccos(rot.a)  # Returns between 0 and pi
     mask = half_angles < half_angle
-    r = r[mask]
-    return r
+    rot_out = rot[mask]
+    return rot_out
