@@ -22,10 +22,11 @@ from tempfile import TemporaryDirectory
 
 from diffpy.structure import Atom, Lattice, Structure
 from h5py import File
+import matplotlib.pyplot as plt
 import numpy as np
 import pytest
 
-from orix.crystal_map import CrystalMap, create_coordinate_arrays, PhaseList
+from orix.crystal_map import CrystalMap, PhaseList, create_coordinate_arrays
 from orix.quaternion import Rotation
 
 
@@ -183,11 +184,11 @@ def angfile_tsl(tmpdir, request):
         Map shape to create.
     step_sizes : tuple of floats
         Step sizes in x and y coordinates in microns.
-    phase_id : np.ndarray
+    phase_id : numpy.ndarray
         Array of map size with phase IDs in header.
     n_unknown_columns : int
         Number of columns with unknown values.
-    rotations : np.ndarray
+    rotations : numpy.ndarray
         A sample, smaller than the map size, of example rotations as
         rows of Euler angle triplets.
     """
@@ -257,9 +258,9 @@ def angfile_astar(tmpdir, request):
         Map shape to create.
     step_sizes : tuple of floats
         Step sizes in x and y coordinates in nanometres.
-    phase_id : np.ndarray
+    phase_id : numpy.ndarray
         Array of map size with phase IDs in header.
-    rotations : np.ndarray
+    rotations : numpy.ndarray
         A sample, smaller than the map size, of example rotations as
         rows of Euler angle triplets.
     """
@@ -321,9 +322,9 @@ def angfile_emsoft(tmpdir, request):
         Map shape to create.
     step_sizes : tuple of floats
         Step sizes in x and y coordinates in nanometres.
-    phase_id : np.ndarray
+    phase_id : numpy.ndarray
         Array of map size with phase IDs in header.
-    rotations : np.ndarray
+    rotations : numpy.ndarray
         A sample, smaller than the map size, of example rotations as
         rows of Euler angle triplets.
     """
@@ -378,7 +379,7 @@ def temp_emsoft_h5ebsd_file(tmpdir, request):
         Map shape to create.
     step_sizes : tuple of floats
         Step sizes in x and y coordinates in microns.
-    rotations : np.ndarray
+    rotations : numpy.ndarray
         A sample, smaller than the map size, of example rotations as
         rows of Euler angle triplets.
     n_top_matches : int
@@ -504,9 +505,9 @@ def temp_bruker_h5ebsd_file(tmpdir, request):
         Map shape to create.
     step_sizes : tuple of floats
         Step sizes in x and y coordinates in microns.
-    phase_id : np.ndarray
+    phase_id : numpy.ndarray
         Array of map size with phase IDs in header.
-    rotations : np.ndarray
+    rotations : numpy.ndarray
         A sample, smaller than the map size, of example rotations as
         rows of Euler angle triplets.
     """
@@ -655,3 +656,73 @@ def crystal_map_input(request, rotations):
 @pytest.fixture
 def crystal_map(crystal_map_input):
     return CrystalMap(**crystal_map_input)
+
+
+@pytest.fixture
+def cif_file(tmpdir):
+    """Actual CIF file of beta double prime phase often seen in Al-Mg-Si
+    alloys.
+    """
+    file_contents = """
+#======================================================================
+
+# CRYSTAL DATA
+
+#----------------------------------------------------------------------
+
+data_VESTA_phase_1
+
+
+_chemical_name_common                  ''
+_cell_length_a                         15.50000
+_cell_length_b                         4.05000
+_cell_length_c                         6.74000
+_cell_angle_alpha                      90
+_cell_angle_beta                       105.30000
+_cell_angle_gamma                      90
+_space_group_name_H-M_alt              'C 2/m'
+_space_group_IT_number                 12
+
+loop_
+_space_group_symop_operation_xyz
+   'x, y, z'
+   '-x, -y, -z'
+   '-x, y, -z'
+   'x, -y, z'
+   'x+1/2, y+1/2, z'
+   '-x+1/2, -y+1/2, -z'
+   '-x+1/2, y+1/2, -z'
+   'x+1/2, -y+1/2, z'
+
+loop_
+   _atom_site_label
+   _atom_site_occupancy
+   _atom_site_fract_x
+   _atom_site_fract_y
+   _atom_site_fract_z
+   _atom_site_adp_type
+   _atom_site_B_iso_or_equiv
+   _atom_site_type_symbol
+   Mg(1)      1.0     0.000000      0.000000      0.000000     Biso  1.000000 Mg
+   Mg(2)      1.0     0.347000      0.000000      0.089000     Biso  1.000000 Mg
+   Mg(3)      1.0     0.423000      0.000000      0.652000     Biso  1.000000 Mg
+   Si(1)      1.0     0.054000      0.000000      0.649000     Biso  1.000000 Si
+   Si(2)      1.0     0.190000      0.000000      0.224000     Biso  1.000000 Si
+   Al         1.0     0.211000      0.000000      0.626000     Biso  1.000000 Al"
+"""
+    f = open(tmpdir.join("betapp.cif"), mode="w")
+    f.write(file_contents)
+    f.close()
+    yield f.name
+    gc.collect()
+
+
+@pytest.fixture(autouse=True)
+def import_to_namespace(doctest_namespace):
+    """Make :mod:`numpy` and :mod:`matplotlib.pyplot` available in
+    docstring examples without having to import them.
+
+    See https://docs.pytest.org/en/stable/how-to/doctest.html#doctest-namespace-fixture.
+    """
+    doctest_namespace["plt"] = plt
+    doctest_namespace["np"] = np
