@@ -21,7 +21,7 @@ import numpy as np
 import pytest
 
 from orix.base import DimensionError
-from orix.quaternion import Quaternion, check_quaternion
+from orix.quaternion import Quaternion
 from orix.vector import Vector3d
 
 # fmt: off
@@ -84,10 +84,10 @@ class TestQuaternion:
 
     def test_norm(self, quaternion):
         q = quaternion
-        assert np.allclose(q.norm.data, (q.data**2).sum(axis=-1) ** 0.5)
+        assert np.allclose(q.norm, (q.data**2).sum(axis=-1) ** 0.5)
 
     def test_unit(self, quaternion):
-        assert np.allclose(quaternion.unit.norm.data, 1)
+        assert np.allclose(quaternion.unit.norm, 1)
 
     def test_conj(self, quaternion):
         q = quaternion
@@ -97,15 +97,15 @@ class TestQuaternion:
     def test_mul(self, quaternion, something):
         q = quaternion
         s = something
-        sa, sb, sc, sd = s.a.data, s.b.data, s.c.data, s.d.data
-        qa, qb, qc, qd = q.a.data, q.b.data, q.c.data, q.d.data
+        sa, sb, sc, sd = s.a, s.b, s.c, s.d
+        qa, qb, qc, qd = q.a, q.b, q.c, q.d
 
         q1 = q * s
         assert isinstance(q1, Quaternion)
-        assert np.allclose(q1.a.data, sa * qa - sb * qb - sc * qc - sd * qd)
-        assert np.allclose(q1.b.data, qa * sb + qb * sa + qc * sd - qd * sc)
-        assert np.allclose(q1.c.data, qa * sc - qb * sd + qc * sa + qd * sb)
-        assert np.allclose(q1.d.data, qa * sd + qb * sc - qc * sb + qd * sa)
+        assert np.allclose(q1.a, sa * qa - sb * qb - sc * qc - sd * qd)
+        assert np.allclose(q1.b, qa * sb + qb * sa + qc * sd - qd * sc)
+        assert np.allclose(q1.c, qa * sc - qb * sd + qc * sa + qd * sb)
+        assert np.allclose(q1.d, qa * sd + qb * sc - qc * sb + qd * sa)
 
     def test_mul_identity(self, quaternion, identity):
         assert np.allclose((quaternion * identity).data, quaternion.data)
@@ -118,13 +118,13 @@ class TestQuaternion:
     def test_inverse(self, quaternion):
         q = quaternion
         assert np.allclose((q * ~q).data, (~q * q).data)
-        assert np.allclose((q * ~q).a.data, 1)
+        assert np.allclose((q * ~q).a, 1)
         assert np.allclose((q * ~q).data[..., 1:], 0)
 
     def test_dot(self, quaternion, something):
         q = quaternion
-        assert np.allclose(q.dot(q).data, np.sum(q.data**2, axis=-1))
-        assert np.allclose(q.dot(something).data, something.dot(q).data)
+        assert np.allclose(q.dot(q), np.sum(q.data**2, axis=-1))
+        assert np.allclose(q.dot(something), something.dot(q))
 
     def test_dot_outer(self, quaternion, something):
         q = quaternion
@@ -134,7 +134,7 @@ class TestQuaternion:
         assert d.shape == q.shape + s.shape
         for i in np.ndindex(q.shape):
             for j in np.ndindex(s.shape):
-                assert np.allclose(d[i + j].data, q[i].dot(s[j]).data)
+                assert np.allclose(d[i + j], q[i].dot(s[j]))
 
     @pytest.mark.parametrize(
         "quaternion, vector, expected",
@@ -157,11 +157,6 @@ class TestQuaternion:
         v_new = q * v
         assert np.allclose(v_new.data, expected)
 
-    def test_check_quat(self):
-        """Check is an oddly named function."""
-        quat = Quaternion([2, 2, 2, 2])
-        assert np.allclose(quat.data, check_quaternion(quat).data)
-
     def test_abcd_properties(self):
         quat = Quaternion([2, 2, 2, 2])
         quat.a = 1
@@ -205,9 +200,14 @@ class TestQuaternion:
         assert isinstance(qo_dask, da.Array)
         qo_numpy2 = Quaternion(qo_dask.compute())
         assert qo_numpy2.shape == 2 * shape
-
         assert np.allclose(qo_numpy.data, qo_numpy2.data)
 
+        # public function .outer() with Dask
+        qo_dask2 = q.outer(q, lazy=True)
+        assert isinstance(qo_dask2, Quaternion)
+        assert qo_dask2.shape == 2 * shape
+        assert np.allclose(qo_numpy.data, qo_dask2.data)
+
     def test_outer_lazy_chunk_size(self):
         shape = (5, 15, 4)
         rng = np.random.default_rng()
@@ -223,3 +223,62 @@ class TestQuaternion:
         assert outer2.chunks == ((5,), (cs2, 2), (5,), (cs2, 2), (4,))
 
         assert np.allclose(outer1.compute(), outer2.compute())
+
+    @pytest.mark.parametrize("shape", [(2, 3), (4, 5, 6), (1, 5), (11,)])
+    def test_outer_vector_lazy(self, shape):
+        rng = np.random.default_rng()
+        new_shape = shape + (4,)
+        abcd = rng.normal(size=np.prod(new_shape)).reshape(shape + (4,))
+        q = Quaternion(abcd).unit
+
+        v = Vector3d(np.random.rand(7, 4, 3)).unit
+
+        qvo_numpy = q.outer(v)
+        assert isinstance(qvo_numpy, Vector3d)
+        assert qvo_numpy.shape == q.shape + v.shape
+
+        # Returns dask array, not Vector3d
+        qvo_dask = q._outer_dask(v)
+        assert isinstance(qvo_dask, da.Array)
+        qvo_numpy2 = Vector3d(qvo_dask.compute())
+        assert qvo_numpy2.shape == qvo_numpy.shape
+        assert np.allclose(qvo_numpy.data, qvo_numpy2.data)
+
+        # public function .outer() with Dask
+        qvo_dask2 = q.outer(v, lazy=True)
+        assert isinstance(qvo_dask2, Vector3d)
+        assert qvo_dask2.shape == qvo_numpy.shape
+        assert np.allclose(qvo_numpy.data, qvo_dask2.data)
+
+    def test_outer_lazy_progressbar_stdout(self, capsys):
+        rng = np.random.default_rng()
+        shape = (5, 3)
+        new_shape = shape + (4,)
+        abcd = rng.normal(size=np.prod(new_shape)).reshape(shape + (4,))
+        q = Quaternion(abcd).unit
+        # other is Quaternion
+        _ = q.outer(q, lazy=True, progressbar=True)
+        out, _ = capsys.readouterr()
+        assert "Completed" in out
+        _ = q.outer(q, lazy=True, progressbar=False)
+        out, _ = capsys.readouterr()
+        assert not out
+        # test other is Vector3d
+        v = Vector3d(np.random.rand(2, 3, 3)).unit
+        _ = q.outer(v, lazy=True, progressbar=True)
+        out, _ = capsys.readouterr()
+        assert "Completed" in out
+        _ = q.outer(v, lazy=True, progressbar=False)
+        out, _ = capsys.readouterr()
+        assert not out
+
+    def test_outer_dask_wrong_type_raises(self):
+        shape = (5,)
+        rng = np.random.default_rng()
+        new_shape = shape + (4,)
+        abcd = rng.normal(size=np.prod(new_shape)).reshape(shape + (4,))
+        q = Quaternion(abcd)
+        # not Quaternion or Vector3d
+        other = np.random.rand(7, 3)
+        with pytest.raises(TypeError, match="Other must be Quaternion or Vector3d"):
+            q._outer_dask(other)
