@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2021 the orix developers
+# Copyright 2018-2022 the orix developers
 #
 # This file is part of orix.
 #
@@ -19,7 +19,7 @@
 import numpy as np
 import pytest
 
-from orix.crystal_map.crystal_map_properties import CrystalMapProperties
+from orix.crystal_map import CrystalMapProperties
 
 
 class TestCrystalMapProperties:
