@@ -24,7 +24,6 @@ import numpy as np
 
 from orix.vector import SphericalRegion, Vector3d
 
-
 _EDGE_STEPS = 1000
 
 
@@ -43,7 +42,8 @@ class FundamentalSector(SphericalRegion):
     _pole = -1
 
     @property
-    def vertices(self):
+    def vertices(self) -> Vector3d:
+        """Return the sector vertices."""
         n = self.size
         if n == 0:
             return Vector3d.empty()
@@ -53,8 +53,8 @@ class FundamentalSector(SphericalRegion):
             return Vector3d(u[u <= self]).unique().unit
 
     @property
-    def center(self):
-        """Center vector of the fundamental sector.
+    def center(self) -> Vector3d:
+        """Return the center vector of the fundamental sector.
 
         Taken from MTEX' :code:`sphericalRegion.center`.
         """
@@ -65,7 +65,7 @@ class FundamentalSector(SphericalRegion):
             center = self
         elif n_vertices < 3:
             # Find the pair of maximum angle
-            angles = self.angle_with(self.reshape(n_normals, 1)).data
+            angles = self.angle_with(self.reshape(n_normals, 1))
             indices = np.argmax(angles, axis=1)
             center = self[indices].mean()
         elif n_vertices < 4:
@@ -77,18 +77,18 @@ class FundamentalSector(SphericalRegion):
             center = self._center
         else:
             # Avoid circular import
-            from orix.sampling import sample_S2_cube_mesh
+            from orix.sampling import sample_S2
 
-            v_all = sample_S2_cube_mesh(resolution=1)
+            v_all = sample_S2(resolution=1, method="spherified_cube_corner")
             v = v_all[v_all < self]
             center = v.mean()
 
         return Vector3d(center)
 
     @property
-    def edges(self):
-        """Unit vectors which delineates the region in the stereographic
-        projection.
+    def edges(self) -> Vector3d:
+        """Return the unit vectors which delineates the region in the
+        stereographic projection.
 
         They are sorted in the counter-clockwise direction around the
         sector center in the stereographic projection.
@@ -114,7 +114,7 @@ class FundamentalSector(SphericalRegion):
             ci_inside = ci[ci <= self]
             v_keep = Vector3d(np.vstack((ci_inside.data, vi.data)))
             v_keep = v_keep.unique()
-            order = np.lexsort((v_keep.azimuth.data, v_keep.polar.data))
+            order = np.lexsort((v_keep.azimuth, v_keep.polar))
             v_keep = v_keep[order]
             v_n = v_keep.size
             edges[j : j + v_n] = v_keep.data
@@ -127,26 +127,30 @@ class FundamentalSector(SphericalRegion):
         return sorted_edges.squeeze()
 
 
-def _order_to_sort_around_center(v, center, pole=-1):
+def _order_to_sort_around_center(
+    v: Vector3d, center: Vector3d, pole: int = -1
+) -> np.ndarray:
     vz = Vector3d.zvector()
     if pole == 1:
         vz = -vz
-    angle = vz.angle_with(center).data
+    angle = vz.angle_with(center)
     axis = vz.cross(center)
     v_rotated = v.rotate(axis=axis, angle=-angle)
 
-    order1 = np.argsort(v_rotated.azimuth.data)
-    idx_closest_to_001 = np.argmax(v[order1].dot(vz).data)
+    order1 = np.argsort(v_rotated.azimuth)
+    idx_closest_to_001 = np.argmax(v[order1].dot(vz))
     order2 = np.roll(order1, shift=-idx_closest_to_001)
 
     return order2
 
 
-def _closed_edges_in_hemisphere(edges, sector, pole=-1):
+def _closed_edges_in_hemisphere(
+    edges: Vector3d, sector: FundamentalSector, pole: int = -1
+) -> Vector3d:
     if pole == -1:
-        is_outside = edges.polar.data >= np.pi / 2
+        is_outside = edges.polar >= np.pi / 2
     else:  # pole == 1
-        is_outside = edges.polar.data <= np.pi / 2
+        is_outside = edges.polar <= np.pi / 2
 
     if not np.any(is_outside):
         return edges
@@ -159,7 +163,7 @@ def _closed_edges_in_hemisphere(edges, sector, pole=-1):
         edges_inside = edges[~is_outside]
         azimuth_before_equator = edges_inside[
             [idx_after_crossing_equator - 1, idx_after_crossing_equator]
-        ].azimuth.data
+        ].azimuth
         v_before_equator = Vector3d.from_polar(
             azimuth_before_equator, polar=[np.pi / 2] * 2
         )
